/*
 * Copyright 2019 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.foundation.text.demos

import androidx.compose.Composable
import androidx.compose.state
import androidx.ui.core.Modifier
import androidx.compose.foundation.ScrollableColumn
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.BaseTextField
import androidx.compose.foundation.ExperimentalFoundationApi
import androidx.ui.unit.dp

@Composable
@OptIn(ExperimentalFoundationApi::class)
fun TextFieldWithScrollerDemo() {
    ScrollableColumn {
        val state = state {
            TextFieldValue(
                text = List(100) { "Line: $it" }.joinToString("\n")
            )
        }
        BaseTextField(
            value = state.value,
            onValueChange = { state.value = it },
            modifier = Modifier
                .padding(20.dp)
        )
    }
}
